All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 1/9] mount.nfs: Fix nfs4mount_s prototype.
@ 2007-08-24 17:11 Chuck Lever
  2007-08-24 22:08 ` Neil Brown
  0 siblings, 1 reply; 4+ messages in thread
From: Chuck Lever @ 2007-08-24 17:11 UTC (permalink / raw)
  To: neilb; +Cc: nfs

The definition of nfs4mount_s in utils/mount/stropts.c doesn't match the
prototype declared in utils/mount/stropts.h.

Signed-off-by: Chuck Lever <chuck.lever@oracle.com>
---

 utils/mount/stropts.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/utils/mount/stropts.c b/utils/mount/stropts.c
index 95392a1..ca79ce0 100644
--- a/utils/mount/stropts.c
+++ b/utils/mount/stropts.c
@@ -37,6 +37,7 @@
 #include "nls.h"
 #include "nfs_mount.h"
 #include "mount_constants.h"
+#include "stropts.h"
 #include "error.h"
 #include "network.h"
 
@@ -286,13 +287,13 @@ fail:
  * @extra_opts:	pointer to C string containing fs-specific mount options
  *		(possibly also a return argument)
  * @fake:	flag indicating whether to carry out the whole operation
  * @bg:		one if this is a backgrounded mount attempt
  *
  * XXX: need to handle bg, fg, and retry options.
  *
  */
 int nfs4mount_s(const char *spec, const char *node, int flags,
-		char **extra_opts, int fake)
+		char **extra_opts, int fake, int child)
 {
 	int retval = EX_FAIL;
 


-------------------------------------------------------------------------
This SF.net email is sponsored by: Splunk Inc.
Still grepping through log files to find problems?  Stop.
Now Search log events and configuration files using AJAX and a browser.
Download your FREE copy of Splunk now >>  http://get.splunk.com/
_______________________________________________
NFS maillist  -  NFS@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/nfs

^ permalink raw reply related	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2007-08-28  0:00 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2007-08-24 17:11 [PATCH 1/9] mount.nfs: Fix nfs4mount_s prototype Chuck Lever
2007-08-24 22:08 ` Neil Brown
     [not found]   ` <46D30F84.302@oracle.com>
@@ -286,13 +287,13 @@ fail:
  *		(possibly also a return argument)
  * @fake:	flag indicating whether to carry out the whole operation
- * @bg:		one if this is a backgrounded mount attempt
+ * @child:	one if this is a backgrounded mount
  *
  * XXX: need to handle bg, fg, and retry options.
2007-08-27 21:02     ` Neil Brown
2007-08-27 23:58       ` Chuck Lever

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.